<!-- warning: Please don't edit this file. It was automatically generated. -->

# winrt-Microsoft.UI.Xaml.Automation.Provider

Windows Runtime (WinRT) APIs for for the `Microsoft.UI.Xaml.Automation.Provider` namespace.

This package provides the `winrt.microsoft.ui.xaml.automation.provider` module.
